==> flame_forge2d-0.14.0.tar.gz: README.md <==
<!-- markdownlint-disable MD013 -->
<p align="center">
  <a href="https://github.com/flame-engine/forge2d">
    <img alt="flame" width="300px" src="https://raw.githubusercontent.com/flame-engine/forge2d/main/design/with-text.png">
  </a>
</p>

<p align="center">
Adds support for <a href="https://github.com/flame-engine/forge2d">Forge2d</a>, the Box2d-based physics engine, to your <a href="https://github.com/flame-engine/flame">Flame</a> games.
</p>

<p align="center">
  <a title="Pub" href="https://pub.dev/packages/flame_forge2d" ><img src="https://img.shields.io/pub/v/flame_forge2d.svg?style=popout" /></a>
  <a title="Test" href="https://github.com/flame-engine/flame/actions?query=workflow%3Acicd+branch%3Amain"><img src="https://github.com/flame-engine/flame/workflows/cicd/badge.svg?branch=main&event=push"/></a>
  <a title="Discord" href="https://discord.gg/pxrBmy4"><img src="https://img.shields.io/discord/509714518008528896.svg"/></a>
  <a title="Melos" href="https://github.com/invertase/melos"><img src="https://img.shields.io/badge/maintained%20with-melos-f700ff.svg"/></a>
</p>

---
<!-- markdownlint-enable MD013 -->

<!-- markdownlint-disable-next-line MD002 -->

# flame_forge2d

This library acts as a bridge between [Forge2D](https://github.com/flame-engine/forge2d) (our port
of Box2D) and the Flame game engine.


## Installation

Check [pub.dev](https://pub.dev/packages/flame_forge2d/install) for the latest version, and also
remember to add the latest version of [Flame](https://pub.dev/packages/flame/install) to your
`pubspec.yaml` file.


## Examples

In the example folder of this directory you can find some
[examples](https://github.com/flame-engine/flame/tree/main/examples/lib/stories/bridge_libraries/forge2d),
and you can also find some examples in the
[Forge2D repository](https://github.com/flame-engine/forge2d/tree/main/example).


## Documentation

Some more documentation can be found
[here](https://docs.flame-engine.org/main/other_modules/forge2d.html).

==> flame_forge2d-0.15.1.tar.gz: README.md <==
<!-- markdownlint-disable MD013 -->
<p align="center">
  <a href="https://github.com/flame-engine/forge2d">
    <img alt="flame" width="300px" src="https://raw.githubusercontent.com/flame-engine/forge2d/main/design/with-text.png">
  </a>
</p>

<p align="center">
Adds support for <a href="https://github.com/flame-engine/forge2d">Forge2d</a>, the Box2d-based physics engine, to your <a href="https://github.com/flame-engine/flame">Flame</a> games.
</p>

<p align="center">
  <a title="Pub" href="https://pub.dev/packages/flame_forge2d" ><img src="https://img.shields.io/pub/v/flame_forge2d.svg?style=popout" /></a>
  <a title="Test" href="https://github.com/flame-engine/flame/actions?query=workflow%3Acicd+branch%3Amain"><img src="https://github.com/flame-engine/flame/workflows/cicd/badge.svg?branch=main&event=push"/></a>
  <a title="Discord" href="https://discord.gg/pxrBmy4"><img src="https://img.shields.io/discord/509714518008528896.svg"/></a>
  <a title="Melos" href="https://github.com/invertase/melos"><img src="https://img.shields.io/badge/maintained%20with-melos-f700ff.svg"/></a>
</p>

---
<!-- markdownlint-enable MD013 -->

<!-- markdownlint-disable-next-line MD002 -->

# flame_forge2d

This library acts as a bridge between [Forge2D](https://github.com/flame-engine/forge2d) (our port
of Box2D) and the Flame game engine.


## Installation

Check [pub.dev](https://pub.dev/packages/flame_forge2d/install) for the latest version, and also
remember to add the latest version of [Flame](https://pub.dev/packages/flame/install) to your
`pubspec.yaml` file.


## Examples

In the example folder of this directory you can find some
[examples](https://github.com/flame-engine/flame/tree/main/examples/lib/stories/bridge_libraries/flame_forge2d),
and you can also find some examples in the
[Forge2D repository](https://github.com/flame-engine/forge2d/tree/main/packages/forge2d/example).


## Documentation

Some more documentation can be found
[here](https://docs.flame-engine.org/main/bridge_packages/flame_forge2d/flame_forge2d.html).
